:github_url: https://github.com/stephane-caron/lpsolvers/tree/main/doc/src/supported-solvers.rst

*****************
Supported solvers
*****************

CVXOPT
======

.. automodule:: lpsolvers.cvxopt_
    :members:

CVXPY
=====

.. automodule:: lpsolvers.cvxpy_
    :members:

cdd
===

.. automodule:: lpsolvers.cdd_
    :members:

PDLP
====

.. automodule:: lpsolvers.pdlp_
    :members:

ProxQP
======

.. automodule:: lpsolvers.proxqp_
    :members:
